@@ -6,65 +6,40 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( xml_to_entry_node add_entry_node_to_info_hash json_to_hash );
+our @EXPORT_OK = qw( add_entry_to_info_hash json_to_hash );
 
-use JSON        qw( decode_json );
-use URI         qw();
-use URI::Escape qw( uri_escape );
-use XML::LibXML qw();
+use JSON qw( decode_json );
 
 use App::YTDL::Helper qw( sec_to_time insert_sep );
 
 
 
-sub _xml_node_to_xpc {
-    my ( $node ) = @_;
-    my $xpc = XML::LibXML::XPathContext->new( $node );
-    $xpc->registerNs( 'xmlns', 'http://www.w3.org/2005/Atom' );
-    $xpc->registerNs( 'media', 'http://search.yahoo.com/mrss/' );
-    $xpc->registerNs( 'gd',    'http://schemas.google.com/g/2005' );
-    $xpc->registerNs( 'yt',    'http://gdata.youtube.com/schemas/2007' );
-    return $xpc;
-}
-
-
-sub xml_to_entry_node {
-    my ( $opt, $xml ) = @_;
-    my $doc = XML::LibXML->load_xml( string => $xml );
-    my $root = $doc->documentElement();
-    my $xpc = _xml_node_to_xpc( $root );
-    my $xpath = $xpc->exists( '/xmlns:feed/xmlns:entry' ) ? '/xmlns:feed/xmlns:entry' : '/xmlns:entry';
-    my @nodes = $xpc->findnodes( $xpath );
-    return @nodes;
-}
-
-
-sub add_entry_node_to_info_hash {
+sub add_entry_to_info_hash {
     my ( $opt, $info, $entry, $type, $list_id ) = @_;
     die '$entry node not defined!' if ! defined $entry;
     die 'empty $entry node!'       if ! $entry;
-    my $xpc = _xml_node_to_xpc( $entry );
-    my $uri = URI->new( $xpc->findvalue( './media:group/media:player/@url' ) );
-    my %params = $uri->query_form;
-    my $video_id = uri_escape( $params{v} );
+    my $video_id = $entry->{'media$group'}{'yt$videoid'}{'$t'};
     die 'no video_id!' if ! $video_id;
-    my $title       = $xpc->findvalue( './media:group/media:title' );
-    my $description = $xpc->findvalue( './media:group/media:description' );
-    my $keywords    = $xpc->findvalue( './media:group/media:keywords' );
-    my $author      = $xpc->findvalue( './xmlns:author/xmlns:name' );
-    my $content     = $xpc->findvalue( './xmlns:content' );
-    my $published   = $xpc->findvalue( './xmlns:published' );
-    my $seconds     = $xpc->findvalue( './media:group/yt:duration/@seconds' );
-    my $avg_rating  = $xpc->findvalue( './gd:rating/@average' );
-    my $num_raters  = $xpc->findvalue( './gd:rating/@numRaters' );
-    my $view_count  = $xpc->findvalue( './yt:statistics/@viewCount' );
-    my $author_uri  = $xpc->findvalue( './xmlns:author/xmlns:uri' );
-    #my $updated     = $xpc->findvalue( './xmlns:updated' );
+    my $title       = $entry->{'title'}{'$t'};
+    my $description = $entry->{'media$group'}{'media$description'}{'$t'};
+    my $keywords    = $entry->{'media$group'}{'media$keywords'}{'$t'};
+    my $author      = $entry->{'author'}[0]{'name'}{'$t'};
+    my $author_uri  = $entry->{'author'}[0]{'uri'}{'$t'};
+    my $user_id     = $entry->{'author'}[0]{'yt$userId'}{'$t'};
+    #my $categories  = $entry->{'media$group'}{'media$category'}[0]{'$t'};
+    my $published   = $entry->{'published'}{'$t'};
+    my $seconds     = $entry->{'media$group'}{'yt$duration'}{'seconds'};
+    my $avg_rating  = $entry->{'gd$rating'}{'average'};
+    my $num_raters  = $entry->{'gd$rating'}{'num_raters'};
+    my $view_count  = $entry->{'yt$statistics'}{'viewCount'};
+    my $likes       = $entry->{'yt$rating'}{'numLikes'};
+    my $dislikes    = $entry->{'yt$rating'}{'numDislikes'};
     $info->{$video_id} = {
         uploader    => $author,
         author_uri  => $author_uri,
+        user_id     => $user_id,
         avg_rating  => $avg_rating,
-        content     => $content,
+        #categories  => $categories,
         description => $description,
         keywords    => $keywords,
         duration    => $seconds,
@@ -73,6 +48,8 @@ sub add_entry_node_to_info_hash {
         title       => $title,
         video_id    => $video_id,
         view_count  => $view_count,
+        likes       => $likes,
+        dislikes    => $dislikes,
     };
     if ( $info->{$video_id}{author_uri} && $info->{$video_id}{author_uri} =~ m|/users/([^$opt->{invalid_char}]+)| ) {
         $info->{$video_id}{uploader_id} = $1;
@@ -102,9 +79,9 @@ sub json_to_hash {
     }
     my $video_id = $h_ref->{id} // $h_ref->{title};
     $tmp->{$video_id}{video_id} = $video_id;
-    my @keys = ( qw( uploader categories uploader_id description format_id dislike_count dislike_count
+    my @keys = ( qw( uploader uploader_id description format_id dislike_count dislike_count
                      duration extractor extractor_key like_coun playlist_id title upload_date view_count ) );
-                     # age_limit annotations fulltitle playlist stitle
+                     # age_limit annotations fulltitle playlist stitle categories
     for my $key ( @keys ) {
         if ( defined $h_ref->{$key} ) {
             $tmp->{$video_id}{$key} = $h_ref->{$key};
