@@ -11,7 +11,7 @@ our @EXPORT_OK = qw( read_history_files channel_history_menu add_channel_to_hist
 use List::MoreUtils qw( none );
 use Term::Choose    qw( choose );
 
-use App::YTDL::Helper qw( read_json write_json );
+use App::YTDL::Helper   qw( read_json write_json );
 
 
 
@@ -22,49 +22,9 @@ sub read_history_files {
     if ( $opt->{max_channels} ) {
         if ( -e $opt->{s_channel_file} ) {
             $opt->{channel_sticky} = read_json( $opt->{s_channel_file} );
-
-            ### keep this some time ###############################################################
-            for my $url ( keys %{$opt->{channel_sticky}} ) {
-                $opt->{channel_sticky}{$url}{uploader}    =         delete $opt->{channel_sticky}{$url}{channel}       if $opt->{channel_sticky}{$url}{channel};
-                $opt->{channel_sticky}{$url}{uploader_id} =         delete $opt->{channel_sticky}{$url}{channel_id}    if $opt->{channel_sticky}{$url}{channel_id};
-                $opt->{channel_sticky}{$url}{extractor}   = lcfirst delete $opt->{channel_sticky}{$url}{extractor_key} if $opt->{channel_sticky}{$url}{extractor_key};
-                delete $opt->{channel_sticky}{$url}{channel_url};
-                if ( $opt->{channel_sticky}{$url}{extractor} eq 'youtube' ) {
-                    if ( $url =~ /^c#([^#]+)\z/ ) {
-                        my $new_url = "https://www.youtube.com/user/$1";
-                        $opt->{channel_sticky}{$new_url} = delete $opt->{channel_sticky}{$url};
-                    }
-                }
-                if ( $url =~ /^http:(.+)\z/ ) {
-                    my $new_url = "https:$1";
-                    $opt->{channel_sticky}{$new_url} = delete $opt->{channel_sticky}{$url};
-                }
-            }
-            #######################################################################################
-
         }
         if ( -e $opt->{h_channel_file} ) {
             $opt->{channel_history} = read_json( $opt->{h_channel_file} );
-
-            ### keep this some time ###############################################################
-            for my $url ( keys %{$opt->{channel_history}} ) {
-                $opt->{channel_history}{$url}{uploader}    =         delete $opt->{channel_history}{$url}{channel}       if $opt->{channel_history}{$url}{channel};
-                $opt->{channel_history}{$url}{uploader_id} =         delete $opt->{channel_history}{$url}{channel_id}    if $opt->{channel_history}{$url}{channel_id};
-                $opt->{channel_history}{$url}{extractor}   = lcfirst delete $opt->{channel_history}{$url}{extractor_key} if $opt->{channel_history}{$url}{extractor_key};
-                delete $opt->{channel_history}{$url}{channel_url};
-                if ( $opt->{channel_history}{$url}{extractor} eq 'youtube' ) {
-                    if ( $url =~ /^c#([^#]+)\z/ ) {
-                        my $new_url = "https://www.youtube.com/user/$1";
-                        $opt->{channel_history}{$new_url} = delete $opt->{channel_history}{$url};
-                    }
-                }
-                if ( $url =~ /^http:(.+)\z/ ) {
-                    my $new_url = "https:$1";
-                    $opt->{channel_history}{$new_url} = delete $opt->{channel_history}{$url};
-                }
-            }
-            #######################################################################################
-
         }
     }
 }
@@ -72,15 +32,12 @@ sub read_history_files {
 
 sub channel_history_menu {
     my ( $opt ) = @_;
-    my $list_size_idx = $opt->{list_size_idx};
 
     MENU : while ( 1 ) {
-        my @list_size = ( '  ALL', '  50' );
-        my $list_size_regexp = join '|', map { quotemeta } @list_size;
-        my ( $channel, $sticky ) = ( '- Channel', '  Sticky' );
+        my ( $channel, $sticky ) = ( '  Channel', '  Sticky' );
         # Choose
         my $choice = choose(
-            [ undef, $channel, $sticky, $list_size[$list_size_idx] ],
+            [ undef, $channel, $sticky ],
             { prompt => 'Choose:', layout => 3, undef => '  QUIT' }
         );
         if ( ! defined $choice ) {
@@ -88,14 +45,14 @@ sub channel_history_menu {
         }
         elsif ( $choice eq $channel ) {
             my ( $sticky,  $sticky_url )  = _sticky_name_and_url( $opt->{channel_sticky} );
-            my ( $history, $history_url, $removed_next ) = _history_name_and_url( $opt, $opt->{channel_history} );
+            my ( $history, $history_url, $last ) = _history_name_and_url( $opt, $opt->{channel_history} );
             my $prompt = 'Channels:' . "\n";
             my @ids;
 
             CHANNEL: while ( 1 ) {
                 my $confirm = '  CONFIRM';
                 my @pre = ( undef, $confirm );
-                my $choices = _channel_choices( \@pre, $sticky, $history, $removed_next );
+                my $choices = _channel_choices( \@pre, $sticky, $history, $last );
                 # Choose
                 my @indexes = choose(
                     $choices,
@@ -118,15 +75,15 @@ sub channel_history_menu {
                         $i -= @pre;
                         if ( $i <= $#$sticky ) {
                             push @ids, $sticky_url->[$i];
-                            $prompt .= sprintf "= %s (%s)\n", $sticky->[$i], $opt->{channel_sticky}{$sticky_url->[$i]}{uploader_id};
+                            $prompt .= sprintf "= %s (%s)\n", $sticky->[$i], $opt->{channel_sticky}{$sticky_url->[$i]}{channel_id};
                         }
                         else {
                             $i -= @$sticky;
                             push @ids, $history_url->[$i];
-                            $prompt .= sprintf "= %s (%s)\n", $history->[$i], $opt->{channel_history}{$history_url->[$i]}{uploader_id};
+                            $prompt .= sprintf "= %s (%s)\n", $history->[$i], $opt->{channel_history}{$history_url->[$i]}{channel_id};
                         }
                     }
-                    $opt->{max_videos} = $list_size[$list_size_idx] =~ /\D(\d+)/ ? $1 : 0;
+                    #last MENU;
                     return @ids;
                 }
                 else {
@@ -134,12 +91,12 @@ sub channel_history_menu {
                         $i -= @pre;
                         if ( $i <= $#$sticky ) {
                             push @ids, $sticky_url->[$i];
-                            $prompt .= sprintf "= %s (%s)\n", $sticky->[$i], $opt->{channel_sticky}{$sticky_url->[$i]}{uploader_id};
+                            $prompt .= sprintf "= %s (%s)\n", $sticky->[$i], $opt->{channel_sticky}{$sticky_url->[$i]}{channel_id};
                         }
                         else {
                             $i -= @$sticky;
                             push @ids, $history_url->[$i];
-                            $prompt .= sprintf "= %s (%s)\n", $history->[$i], $opt->{channel_history}{$history_url->[$i]}{uploader_id};
+                            $prompt .= sprintf "= %s (%s)\n", $history->[$i], $opt->{channel_history}{$history_url->[$i]}{channel_id};
                         }
                     }
                 }
@@ -149,7 +106,6 @@ sub channel_history_menu {
             my ( $sticky,  $sticky_url )  = _sticky_name_and_url( $opt->{channel_sticky} );
             my ( $history, $history_url ) = _history_name_and_url( $opt, $opt->{channel_history} );
             my $changed = 0;
-
             STICKY: while ( 1 ) {
                 my @pre = ( undef );
                 my $idx = choose(
@@ -181,21 +137,16 @@ sub channel_history_menu {
                 }
             }
         }
-        if ( $choice =~ /^$list_size_regexp\z/ ) {
-            $list_size_idx++;
-            $list_size_idx = 0 if $list_size_idx > $#list_size;
-            next MENU;
-        }
     }
 }
 
 
 sub _channel_choices {
-    my ( $pre, $sticky, $history, $removed_next ) = @_;
+    my ( $pre, $sticky, $history, $last ) = @_;
     my $choices = [ @$pre, map( "* $_", @$sticky ) ];
     for my $i ( 0 .. $#$history ) {
-        push @$choices, "  $history->[$i]" if ! $removed_next->[$i];
-        push @$choices, "| $history->[$i]" if   $removed_next->[$i];
+            push @$choices, "  $history->[$i]" if ! $last->[$i];
+            push @$choices, "| $history->[$i]" if   $last->[$i];
     }
     return $choices;
 }
@@ -205,30 +156,30 @@ sub _history_name_and_url {
     my ( $opt, $ref ) = @_;
     my $tmp_name = [];
     my $tmp_url  = [];
-    my $tmp_removed_next = [];
+    my $tmp_last = [];
     my $count = 0;
     for my $key ( sort { $ref->{$b}{timestamp} <=> $ref->{$a}{timestamp} } keys %$ref ) {
         $count++;
-        push @$tmp_name, $ref->{$key}{uploader};
+        push @$tmp_name, $ref->{$key}{channel};
         push @$tmp_url, $key;
-        push @$tmp_removed_next, $count >= $opt->{max_channels} ? 1 : 0;
+        push @$tmp_last, $count >= $opt->{max_channels} ? 1 : 0;
     }
     my $history_name = [];
     my $history_url  = [];
-    my $removed_next = [];
+    my $history_last = [];
     if ( ! $opt->{channel_by_timestamp} ) {
         for my $i ( sort { lc $tmp_name->[$a] cmp lc $tmp_name->[$b] } 0 .. $#$tmp_name ) {
             push @$history_name, $tmp_name->[$i];
             push @$history_url,  $tmp_url->[$i];
-            push @$removed_next, $tmp_removed_next->[$i];
+            push @$history_last, $tmp_last->[$i];
         }
     }
     else {
         $history_name = $tmp_name;
         $history_url  = $tmp_url;
-        $removed_next = $tmp_removed_next;
+        $history_last = $tmp_last;
     }
-    return $history_name, $history_url, $removed_next;
+    return $history_name, $history_url, $history_last;
 }
 
 
@@ -236,8 +187,8 @@ sub _sticky_name_and_url {
     my ( $ref ) = @_;
     my $sticky_name = [];
     my $sticky_url  = [];
-    for my $key ( sort { lc $ref->{$a}{uploader} cmp lc $ref->{$b}{uploader} } keys %$ref ) {
-        push @$sticky_name, $ref->{$key}{uploader};
+    for my $key ( sort { lc $ref->{$a}{channel} cmp lc $ref->{$b}{channel} } keys %$ref ) {
+        push @$sticky_name, $ref->{$key}{channel};
         push @$sticky_url, $key;
     }
     return $sticky_name, $sticky_url;
@@ -245,21 +196,22 @@ sub _sticky_name_and_url {
 
 
 sub add_channel_to_history {
-    my ( $opt, $info, $ex, $video_id ) = @_;
-    my $uploader    = $info->{$ex}{$video_id}{uploader};
-    my $uploader_id = $info->{$ex}{$video_id}{uploader_id};
-    return if ! length $uploader_id;
-    my $uploader_url;
-    $uploader_url = 'https://www.youtube.com/user/' if $ex eq 'youtube';
-    $uploader_url = 'https://vimeo.com/'            if $ex eq 'vimeo';
-    if ( defined $uploader_url ) {
-        $uploader_url .= $uploader_id;
-        if ( none{ $uploader_url eq $_ } keys %{$opt->{channel_sticky}} ) {
-            $opt->{channel_history}{$uploader_url} = {
-                uploader     => $uploader,
-                uploader_id  => $uploader_id,
-                extractor    => $ex,
-                timestamp    => time(),
+    my ( $opt, $info, $video_id ) = @_;
+    my $channel       = $info->{$video_id}{uploader};
+    my $channel_id    = $info->{$video_id}{uploader_id};
+    my $extractor_key = $info->{$video_id}{extractor_key};
+    my $channel_url;
+    $channel_url = 'c#'                if $info->{$video_id}{extractor_key} eq 'Youtube';
+    $channel_url = 'http://vimeo.com/' if $info->{$video_id}{extractor_key} eq 'Vimeo';
+    if ( defined $channel_url ) {
+        $channel_url .= $channel_id;
+        if ( none{ $channel_url eq $_ } keys %{$opt->{channel_sticky}} ) {
+            $opt->{channel_history}{$channel_url} = {
+                channel_url   => $channel_url,
+                channel       => $channel,
+                channel_id    => $channel_id,
+                extractor_key => $extractor_key,
+                timestamp     => time(),
             };
         }
     }
