@@ -10,7 +10,7 @@ our @EXPORT_OK = qw( get_download_infos );
 
 use File::Spec::Functions qw( catfile catdir );
 
-use List::MoreUtils   qw( any none first_index );
+use List::MoreUtils   qw( any first_index );
 use Term::ANSIScreen  qw( :cursor :screen );
 use Term::Choose      qw( choose );
 use Unicode::GCString qw();
@@ -19,6 +19,7 @@ use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
 use App::YTDL::Info_Print qw( linefolded_print_info );
 use App::YTDL::Helper     qw( term_size unicode_trim encode_stdout_lax encode_fs read_json write_json );
+use App::YTDL::History    qw( add_channel_to_history write_channel_history_to_file );
 
 
 
@@ -133,36 +134,12 @@ sub get_download_infos {
         binmode STDOUT, ':encoding(console_out)';
         print "\n";
         if ( $opt->{max_channels} && $info->{$video_id}{uploader_id} ) {
-            my $channel       = $info->{$video_id}{uploader};
-            my $channel_id    = $info->{$video_id}{uploader_id};
-            my $extractor_key = $info->{$video_id}{extractor_key};
-            my $channel_url;
-            $channel_url = 'c#'                if $info->{$video_id}{extractor_key} eq 'Youtube';
-            $channel_url = 'http://vimeo.com/' if $info->{$video_id}{extractor_key} eq 'Vimeo';
-            if ( defined $channel_url ) {
-                $channel_url .= $channel_id;
-                if ( none{ $channel_url eq $_ } keys %{$opt->{channel_sticky}} ) {
-                    $opt->{channel_history}{$channel_url} = {
-                        channel_url   => $channel_url,
-                        channel       => $channel,
-                        channel_id    => $channel_id,
-                        extractor_key => $extractor_key,
-                        timestamp     => time(),
-                    };
-                }
-            }
+            add_channel_to_history( $opt, $info, $video_id );
         }
     }
     print "\n";
     if ( $opt->{max_channels} ) {
-        my $c_hist = $opt->{channel_history};
-        my @keys = sort { $c_hist->{$b}{timestamp} <=> $c_hist->{$a}{timestamp} } keys %$c_hist;
-        while ( @keys > $opt->{max_channels} ) {
-            my $key = pop @keys;
-            delete $c_hist->{$key};
-            @keys = sort { $c_hist->{$b}{timestamp} <=> $c_hist->{$a}{timestamp} } keys %$c_hist;
-        }
-        write_json( $opt->{h_channel_file}, $c_hist );
+        write_channel_history_to_file( $opt );
     }
     $opt->{total_nr_videos} = $count;
     if ( ! $opt->{total_nr_videos} ) {
